@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009 - 2025
+* (C) Francesco Mondello 2009 - 2026
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -243,6 +243,16 @@ bool IniSettings::isAutoChechUpdates()
     return enabled;
 }
 
+QString IniSettings::theme()
+{
+    QString theme = "none";
+
+    if (settings->contains("Options/Theme"))
+        theme = settings->value("Options/Theme").toString();
+
+    return theme;
+}
+
 //
 
 void IniSettings::setOutputDir(QString path)
@@ -345,6 +355,11 @@ void IniSettings::setAutoChechUpdates(bool enabled)
     settings->setValue("Options/Check updates", enabled);
 }
 
+void IniSettings::setTheme(const QString &themeName)
+{
+    settings->setValue("Options/Theme", themeName);
+}
+
 void IniSettings::setIsWebPLosslessCompression(const bool &value)
 {
     settings->setValue("Quality/Webp lossless compression", value);
