@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009 - 2025
+* (C) Francesco Mondello 2009 - 2026
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -29,20 +29,28 @@
 #include <QUrl>
 #include <QNetworkReply>
 
+#define VERSION_URL "https://fasterland.net/software-updates/converseen-version.txt"
+#define DESTINATION_URL "https://converseen.fasterland.net/update/"
+
 class UpdateChecker : public QObject
 {
     Q_OBJECT
 public:
     explicit UpdateChecker(QObject *parent = 0);
     void checkForUpdates();
+    bool isUpdateAvailable();
 
 private:
     void checkIfIsNewVersion(int version);
 
     QNetworkAccessManager* mNetworkManager;
+    bool m_update_available;
 
 private slots:
     void onNetworkReply(QNetworkReply* reply);
+
+signals:
+    void updateAvailable(const bool &isAvailable);
 };
 
 #endif // UPDATECHECKER_H
